"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("./base");
const path_1 = require("path");
const util_1 = require("../util");
const errors_1 = require("../../errors");
const fs_1 = require("fs");
/**
 * Handles types with mixed content. Mixed content means there are one or more source
 * file(s) associated with a component with any file extension. Even an entire folder
 * can be considered "the content".
 *
 * __Example Types__:
 *
 * StaticResources, Documents, Bundle Types
 *
 * __Example Structures__:
 *
 *```text
 * foos/
 * ├── myFoo/
 * |   ├── fooFolder/
 * |      ├── foofighters.x
 * |   ├── foo.y
 * |   ├── fooBar.z
 * ├── myFoo.ext-meta.xml
 * bars/
 * ├── myBar.xyz
 * ├── myBar.ext2-meta.xml
 *```
 */
class MixedContent extends base_1.BaseSourceAdapter {
    getMetadataXmlPath(pathToSource) {
        const contentPath = this.getPathToContent(pathToSource);
        const rootTypeDirectory = path_1.dirname(contentPath);
        const contentFullName = util_1.parseBaseName(contentPath);
        return util_1.findMetadataXml(rootTypeDirectory, contentFullName);
    }
    getSourcePaths(fsPath, isMetaXml) {
        let contentPath;
        const ignore = new Set();
        if (!isMetaXml) {
            contentPath = this.getPathToContent(fsPath);
            ignore.add(this.getMetadataXmlPath(fsPath));
        }
        else {
            const metadataXml = util_1.parseMetadataXml(fsPath);
            contentPath = util_1.findMetadataContent(path_1.dirname(fsPath), metadataXml.fullName);
            ignore.add(fsPath);
        }
        if (!fs_1.existsSync(contentPath)) {
            throw new errors_1.ExpectedSourceFilesError(this.type, fsPath);
        }
        const sources = util_1.isDirectory(contentPath)
            ? util_1.walk(contentPath, ignore)
            : [contentPath];
        return sources;
    }
    /**
     * "Content" can either be a single file or an entire folder. This will slice
     * the source path accordingly.
     * @param source
     */
    getPathToContent(source) {
        const pathParts = source.split(path_1.sep);
        const typeFolderIndex = pathParts.findIndex(part => part === this.type.directoryName);
        const offset = this.type.inFolder ? 3 : 2;
        return pathParts.slice(0, typeFolderIndex + offset).join(path_1.sep);
    }
}
exports.MixedContent = MixedContent;
//# sourceMappingURL=mixedContent.js.map