"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const adapters_1 = require("./adapters");
const util_1 = require("./util");
const errors_1 = require("../errors");
const _1 = require(".");
/**
 * Primary interface for the metadata registry data. Used to infer information about metadata
 * types and components based on source paths.
 */
class RegistryAccess {
    /**
     * @param data Optional custom registry data.
     */
    constructor(data) {
        this.data = data
            ? // deep freeze a copy, not the original object
                util_1.deepFreeze(JSON.parse(JSON.stringify(data)))
            : // registryData is already frozen
                _1.registryData;
    }
    /**
     * Get metadata type information.
     *
     * @param name Name of the metadata type
     */
    getTypeFromName(name) {
        const lower = name.toLowerCase().replace(/ /g, '');
        if (!this.data.types[lower]) {
            throw new errors_1.TypeInferenceError('error_missing_type_definition', lower);
        }
        return this.data.types[lower];
    }
    /**
     * Get the metadata component(s) from a file path.
     *
     * @param fsPath File path for a piece of metadata
     */
    getComponentsFromPath(fsPath) {
        if (!fs_1.existsSync(fsPath)) {
            throw new errors_1.TypeInferenceError('error_path_not_found', fsPath);
        }
        else if (util_1.isDirectory(fsPath)) {
            throw new errors_1.TypeInferenceError('error_directories_not_supported');
        }
        let typeId;
        // attempt 1 - check if it's a metadata xml file
        const parsedMetaXml = util_1.parseMetadataXml(fsPath);
        if (parsedMetaXml) {
            typeId = this.data.suffixes[parsedMetaXml.suffix];
        }
        // attempt 2 - check if the file is part of a mixed content type
        if (!typeId) {
            const pathParts = new Set(fsPath.split(path_1.sep));
            for (const directoryName of Object.keys(this.data.mixedContent)) {
                if (pathParts.has(directoryName)) {
                    typeId = this.data.mixedContent[directoryName];
                    break;
                }
            }
        }
        // attempt 3 - try treating the file extension name as a suffix
        if (!typeId) {
            // extname include the dot, so we have to remove it to index the suffixes
            const extName = path_1.extname(fsPath).split('.')[1];
            typeId = this.data.suffixes[extName];
        }
        if (!typeId) {
            throw new errors_1.TypeInferenceError('error_could_not_infer_type', fsPath);
        }
        const adapterId = this.data.adapters[typeId];
        const adapter = adapters_1.getAdapter(this.getTypeFromName(typeId), adapterId);
        return [adapter.getComponent(fsPath)];
    }
}
exports.RegistryAccess = RegistryAccess;
//# sourceMappingURL=registryAccess.js.map