/**
 * Properties of a metadata type.
 */
export declare type MetadataType = {
    name: string;
    /**
     * Name of the directory where components are located in a package
     */
    directoryName: string;
    /**
     * Whether or not components are stored in folders.
     *
     * __Examples:__ Reports, Dashboards, Documents, EmailTemplates
     */
    inFolder: boolean;
    /**
     * File suffix
     *
     * Some types may not have one, such as those made up of varying file extensions.
     *
     * __Examples:__ LightningComponentBundles, Documents, StaticResources
     */
    suffix?: string;
    /**
     * Names of the subtypes if the type has any.
     */
    childXmlNames?: string[];
};
/**
 * Source information about a single metadata component.
 */
export declare type MetadataComponent = {
    fullName: string;
    type: MetadataType;
    /**
     * Path to the root metadata xml file.
     */
    xml: SourcePath;
    /**
     * Paths to additional source files, if any.
     */
    sources: SourcePath[];
};
/**
 * File system path to a source file of a metadata component.
 */
export declare type SourcePath = string;
/**
 * Describes the shape of the registry data.
 */
export declare type MetadataRegistry = {
    /**
     * Metadata type definitions
     */
    types: {
        [typeId: string]: MetadataType;
    };
    /**
     * Index mapping file suffixes to type ids.
     */
    suffixes: {
        [suffix: string]: string;
    };
    /**
     * Index mapping directoryNames to type ids for types with mixed content.
     */
    mixedContent: {
        [directoryName: string]: string;
    };
    /**
     * SourceAdapter mappings for types that need an explicit definition.
     */
    adapters: {
        [typeId: string]: string;
    };
};
export declare type MetadataXml = {
    fullName: string;
    suffix: string;
};
/**
 * Infers the source format structure of a metadata component when given a file path.
 */
export interface SourceAdapter {
    getComponent(fsPath: SourcePath): MetadataComponent;
}
